# Welcome to sc3nb's documentation!

```{toctree}
:caption: Overview
:maxdepth: 4

README & Installation <README>
info
support
resources
CHANGELOG

```

```{toctree}
:caption: User Guide
:maxdepth: 2

autogen/notebooks/sc3nb-examples
autogen/notebooks/sclang-examples
supercolliderobjects
autogen/notebooks/osc-communication-examples
autogen/notebooks/helper-examples
autogen/notebooks/timedqueue-examples

```

```{toctree}
:caption: API Reference
:maxdepth: 3

autogen/autoapi/sc3nb/index

```

```{toctree}
:caption: Contributing
:maxdepth: 2

CONTRIBUTING
CONTRIBUTORS

```

# Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
